==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/ArcTangential/ts/ArcTangential_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>ArcTangential</name>
    <message>
        <location filename="../ArcTangential.js" line="+63"/>
        <source>Choose base line or base arc</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wybierz linię bazową lub łuku bazowego</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Choose end point of arc</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wybierz punkt końcowy łuku</translation>
    </message>
    <message>
        <location filename="../ArcTangential.ui" line="+17"/>
        <source>Radius:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź promień:
Promień:</translatorcomment>
        <translation type="unfinished">Promień:</translation>
    </message>
    <message>
        <source>&amp;Tangentially connected</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Stycznie podłączony</translation>
    </message>
    <message>
        <location filename="../ArcTangentialInit.js" line="+2"/>
        <source>&amp;Tangentially Connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to base entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narysuj łuk styczny do jednostki bazowej</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/ArcTangential/ts/ArcTangential_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ArcTangential</name>
    <message>
        <location filename="../ArcTangential.js" line="+63"/>
        <source>Choose base line or base arc</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać linię lub łuk odniesienia</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Choose end point of arc</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać punkt końcowy łuku</translation>
    </message>
    <message>
        <location filename="../ArcTangential.ui" line="+17"/>
        <source>Radius:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź promień:
Promień:</translatorcomment>
        <translation>Promień:</translation>
    </message>
    <message>
        <source>&amp;Tangentially connected</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Stycznie podłączony</translation>
    </message>
    <message>
        <location filename="../ArcTangentialInit.js" line="+2"/>
        <source>&amp;Tangentially Connected</source>
        <translation>&amp;Styczny</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to base entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje łuk styczny do danego obiektu</translation>
    </message>
</context>
</TS>
